Module: Ripple::AttributeMethods::ClassMethods
- Defined in:
- lib/ripple/attribute_methods.rb
Instance Method Summary collapse
-
#define_attribute_methods ⇒ Object
Generates all the attribute-related methods for properties defined on the document, including accessors, mutators and query methods.
- #property(key, type, options = {}) ⇒ Object
Instance Method Details
#define_attribute_methods ⇒ Object
Generates all the attribute-related methods for properties defined on the document, including accessors, mutators and query methods.
51 52 53 |
# File 'lib/ripple/attribute_methods.rb', line 51 def define_attribute_methods super(properties.keys) end |
#property(key, type, options = {}) ⇒ Object
44 45 46 47 |
# File 'lib/ripple/attribute_methods.rb', line 44 def property(key, type, ={}) undefine_attribute_methods super end |