Module: Ripple::Document::InstanceMethods
- Defined in:
- lib/ripple/document.rb
Instance Method Summary collapse
-
#==(comparison_object) ⇒ Object
Returns true if the
comparison_objectis the same object, or is of the same type and has the same key. - #_root_document ⇒ Object
Instance Method Details
#==(comparison_object) ⇒ Object
Returns true if the comparison_object is the same object, or is of the same type and has the same key.
92 93 94 95 96 |
# File 'lib/ripple/document.rb', line 92 def ==(comparison_object) comparison_object.equal?(self) || (comparison_object.class < Document && (comparison_object.instance_of?(self.class) || comparison_object.class.bucket.name == self.class.bucket.name) && comparison_object.key == key && !comparison_object.new?) end |
#_root_document ⇒ Object
87 88 89 |
# File 'lib/ripple/document.rb', line 87 def _root_document self end |