Module: Ripple::Serialization

Extended by:
ActiveSupport::Concern
Includes:
ActiveModel::Serializers::JSON
Defined in:
lib/ripple/serialization.rb

Overview

Provides methods for serializing Ripple documents to external formats (e.g. JSON). By default, embedded documents will be included in the resulting format.

Defined Under Namespace

Modules: InstanceMethods