Module: Ripple::AttributeMethods::ClassMethods
- Defined in:
- lib/ripple/attribute_methods.rb
Instance Method Summary collapse
-
#define_attribute_methods ⇒ Object
Generates all the attribute-related methods for properties defined on the document, including accessors, mutators and query methods.
- #property(key, type, options = {}) ⇒ Object
Instance Method Details
#define_attribute_methods ⇒ Object
Generates all the attribute-related methods for properties defined on the document, including accessors, mutators and query methods.
47 48 49 |
# File 'lib/ripple/attribute_methods.rb', line 47 def define_attribute_methods super(properties.keys) end |
#property(key, type, options = {}) ⇒ Object
40 41 42 43 |
# File 'lib/ripple/attribute_methods.rb', line 40 def property(key, type, ={}) undefine_attribute_methods super end |