Module: Ripple::EmbeddedDocument
- Extended by:
- ActiveSupport::Concern
- Includes:
- Translation
- Defined in:
- lib/ripple/embedded_document.rb,
lib/ripple/embedded_document/finders.rb,
lib/ripple/embedded_document/persistence.rb
Overview
Represents a document model that is composed into or stored in a parent Document. Embedded documents may also embed other documents, have callbacks and validations, but are solely dependent on the parent Document.
Defined Under Namespace
Modules: ClassMethods, Finders, InstanceMethods, Persistence